//
// Copyright (c) 2001-2010 by PDFTron Systems Inc. All Rights Reserved.
//

using System;
using System.Drawing;
using System.Drawing.Drawing2D;

using pdftron;
using pdftron.Common;
using pdftron.Filters;
using pdftron.SDF;
using pdftron.PDF;

namespace ConvertTestCS
{
    /// <summary>
    // The following sample illustrates how to use the PDF::Convert utility class to convert 
    // documents and files to PDF, XPS, SVG, or EMF.
    //
    // Certain file formats such as XPS, EMF, PDF, and raster image formats can be directly 
    // converted to PDF or XPS. Other formats are converted using a virtual driver. To check 
    // if ToPDF (or ToXPS) require that PDFNet printer is installed use Convert::RequiresPrinter(filename). 
    // The installing application must be run as administrator. The manifest for this sample 
    // specifies appropriate the UAC elevation.
    //
    // Note: the PDFNet printer is a virtual XPS printer supported on Vista SP1 and Windows 7, or .NET Framework
    // 3.x or higher. For older versions of .NET Framework running on Windows XP or Vista SP0 you need to install 
    // the XPS Essentials Pack (or equivalent redistributables). 
    /// </summary>
    class Testfile  
    {
        public string inputFile, outputFile;
        public Testfile( string inFile, string outFile ) 
        { 
            inputFile = inFile; 
            outputFile = outFile;
        }
    };

    class Class1
	{
		// Relative path to the folder containing test files.
		const string inputPath =  "../../../../TestFiles/";
		const string outputPath = "../../../../TestFiles/Output/";

        static Boolean ConvertSpecificFormats()
        {
            Boolean err = false;
            try
			{				
                //////////////////////////////////////////////////////////////////////////
				// Start with a PDFDoc to put the results into
				PDFDoc pdfdoc = new PDFDoc();

                pdftron.PDF.Convert.FromXps(pdfdoc, inputPath + "simple-xps.xps" );
                pdftron.PDF.Convert.FromEmf(pdfdoc, inputPath + "simple-emf.emf");

                pdfdoc.Save(outputPath + "ConvertTest_CS_fromXps_and_fromEmf.pdf", SDFDoc.SaveOptions.e_linearized);
                pdfdoc.Close();
				Console.WriteLine("Wrote " + outputPath + "ConvertTest_CS_fromXps_and_fromEmf.pdf");
			}
			catch (PDFNetException e)
			{
				Console.WriteLine(e.Message);
                err = true;
			}
            return err;
        }

        static Boolean ConvertToPdfFromFile()
        {
            System.Collections.ArrayList testfiles = new System.Collections.ArrayList();
			testfiles.Add( new ConvertTestCS.Testfile( "simple-powerpoint_2007.pptx", "ConvertTest_CS_pptx2pdf.pdf"));
            testfiles.Add(new ConvertTestCS.Testfile("simple-text.txt", "ConvertTest_CS_txt2pdf.pdf"));
            testfiles.Add(new ConvertTestCS.Testfile("simple-word_2007.docx", "ConvertTest_CS_docx2pdf.pdf"));
            testfiles.Add(new ConvertTestCS.Testfile("simple-rtf.rtf", "ConvertTest_CS_rtf2pdf.pdf"));
            testfiles.Add(new ConvertTestCS.Testfile("simple-excel_2007.xlsx", "ConvertTest_CS_xlsx2pdf.pdf"));
            testfiles.Add(new ConvertTestCS.Testfile("simple-publisher.pub", "ConvertTest_CS_pub2pdf.pdf"));
            testfiles.Add(new ConvertTestCS.Testfile("butterfly.png", "ConvertTest_CS_png2pdf.pdf"));
            testfiles.Add(new ConvertTestCS.Testfile("simple-emf.emf", "ConvertTest_CS_emf2pdf.pdf"));
            testfiles.Add(new ConvertTestCS.Testfile("simple-xps.xps", "ConvertTest_CS_xps2pdf.pdf"));
            testfiles.Add(new ConvertTestCS.Testfile("simple-webpage.mht", "ConvertTest_CS_mht2pdf.pdf"));
            testfiles.Add(new ConvertTestCS.Testfile("simple-webpage.html", "ConvertTest_CS_html2pdf.pdf"));

            Boolean err = false;
            Boolean uninstallPrinterWhenDone = false;
			if (pdftron.PDF.Convert.Printer.IsInstalled("PDFTron Creator"))
			{
				pdftron.PDF.Convert.Printer.SetPrinterName("PDFTron Creator");
			}
			else if (!pdftron.PDF.Convert.Printer.IsInstalled())
            {
                try
                {
                    Console.WriteLine("Installing printer (requires administrator)");
                    pdftron.PDF.Convert.Printer.Install();
                    Console.WriteLine("Installed printer " + pdftron.PDF.Convert.Printer.GetPrinterName());
                    // the function ConvertToXpsFromFile may require the printer so leave it installed
                    // uninstallPrinterWhenDone = true;
                }
                catch (PDFNetException e)
                {
                    Console.WriteLine("ERROR: Unable to install printer");
                    Console.WriteLine(e.Message);
                    err = true;
                }
            }

            foreach( Testfile file in testfiles )
            {
                try
                {
                    pdftron.PDF.PDFDoc pdfdoc = new PDFDoc();

                    if( pdftron.PDF.Convert.RequiresPrinter(inputPath + file.inputFile))
                    {
                        Console.WriteLine("Printing file: " + file.inputFile);
                    }
                    pdftron.PDF.Convert.ToPdf(pdfdoc, inputPath + file.inputFile); 
                    pdfdoc.Save(outputPath + file.outputFile, SDFDoc.SaveOptions.e_linearized);
                    pdfdoc.Close();
                    pdfdoc = null;
                    Console.WriteLine("Converted file: " + file.inputFile);
                    Console.WriteLine("        to pdf: " + file.outputFile);
                }
                catch (PDFNetException e)
                {
                    Console.WriteLine("ERROR: on input file " + file.inputFile);
                    Console.WriteLine( e.Message );
                    err = true;
                }
            }

            if (uninstallPrinterWhenDone)
            {
                try
                {
                    Console.WriteLine("Uninstalling printer (requires administrator)");
                    pdftron.PDF.Convert.Printer.Uninstall();
                    Console.WriteLine("Uninstalled printer " + pdftron.PDF.Convert.Printer.GetPrinterName());
                }
                catch (PDFNetException e)
                {
                    Console.WriteLine(e.Message);
                    err = true;
                }
            }
            return err;
        }

        static Boolean ConvertToXpsFromFile()
        {
            Boolean err = false;
            try
            {
                pdftron.PDF.Convert.ToXps(inputPath + "butterfly.png", outputPath + "butterfly.xps");
                Console.WriteLine("Wrote " + outputPath + "buttefly.xps");
                pdftron.PDF.Convert.ToXps(inputPath + "simple-word_2007.docx", outputPath + "simple-word_2007.xps");
                Console.WriteLine("Wrote " + outputPath + "simple-word_2007.xps");
                pdftron.PDF.Convert.ToXps(inputPath + "newsletter.pdf", outputPath + "newsletter.xps");
                Console.WriteLine("Wrote " + outputPath + "newsletter.xps");
            }
            catch (PDFNetException e)
            {
                Console.WriteLine(e.Message);
                err = true;
            }
            return err;
        }

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main(string[] args)
		{
			PDFNet.Initialize();
            Boolean err = false;

	        err = ConvertToPdfFromFile();
	        if( err )
	        {
                Console.WriteLine("ConvertFile failed");
	        }
	        else
	        {
		        Console.WriteLine("ConvertFile succeeded");
	        }

	        err = ConvertSpecificFormats();
	        if( err )
	        {
		        Console.WriteLine("ConvertSpecificFormats failed");
	        }
            else
            {
		        Console.WriteLine("ConvertSpecificFormats succeeded");
	        }

            err = ConvertToXpsFromFile();
            if (err)
            {
                Console.WriteLine("ConvertToXpsFromFile failed");
            }
            else
            {
                Console.WriteLine("ConvertToXpsFromFile succeeded");
            }

			PDFNet.Terminate();
            Console.WriteLine("Done.");
		}
	}
}
