//---------------------------------------------------------------------------------------
// Copyright (c) 2001-2010 by PDFTron Systems Inc. All Rights Reserved.
// Consult legal.txt regarding legal and license information.     
//---------------------------------------------------------------------------------------

//---------------------------------------------------------------------------------------
// The following sample illustrates how to convert PDF documents to CMYK TIFF.
// For additional sample code showing how to use PDFDraw class please take a 
// look at PDFDraw sample: http://www.pdftron.com/pdfnet/samplecode.html#PDFDraw
//---------------------------------------------------------------------------------------

using System;
using System.Drawing;

using pdftron;
using pdftron.Common;
using pdftron.PDF;
using pdftron.SDF;

namespace PDFDrawCMYK
{
	class PDFDrawCMYK
	{
		// Relative path to the folder containing test files.
		static string input_path =  "../../../../TestFiles/";
		static string output_path = "../../../../TestFiles/Output/";		
		
		static void Main(string[] args)
		{
			// The first step in every application using PDFNet is to initialize the library. 
			// The library is usually initialized only once, but calling Initialize() multiple times is also fine.
			PDFNet.Initialize();		           

			try 
			{
				// Optional: Set ICC color profiles to fine tune color conversion 
				// for PDF 'device' color spaces. You can use your own ICC profiles. 
				// Standard Adobe color profiles can be download from Adobes site: 
				// http://www.adobe.com/support/downloads/iccprofiles/iccprofiles_win.html
				//
				// Simply drop all *.icc files in PDFNet resource folder or you specify 
				// the full pathname.
				//---
				// PDFNet.SetResourcesPath("../../../../../resources");
				// PDFNet.SetColorManagement();
				// PDFNet.SetDefaultDeviceCMYKProfile("USWebCoatedSWOP.icc"); // will search in PDFNet resource folder.
				// PDFNet.SetDefaultDeviceRGBProfile(@"C:\ICC\AdobeRGB1998.icc"); 

				// Optional: Set predefined font mappings to override default font 
				// substitution for documents with missing fonts. For example:
				//---
				// PDFNet.AddFontSubst("StoneSans-Semibold", "C:/WINDOWS/Fonts/comic.ttf");
				// PDFNet.AddFontSubst("StoneSans", "comic.ttf");  // search for 'comic.ttf' in PDFNet resource folder.
				// PDFNet.AddFontSubst(PDFNet.CharacterOrdering.e_Identity, "C:/WINDOWS/Fonts/arialuni.ttf");
				// PDFNet.AddFontSubst(PDFNet.CharacterOrdering.e_Japan1, "C:/Program Files/Adobe/Acrobat 7.0/Resource/CIDFont/KozMinProVI-Regular.otf");
				// PDFNet.AddFontSubst(PDFNet.CharacterOrdering.e_Japan2, "c:/myfonts/KozMinProVI-Regular.otf");
				//
				// If fonts are in PDFNet resource folder, it is not necessary to specify 
				// the full path name. For example,
				//---
				// PDFNet.AddFontSubst(PDFNet.CharacterOrdering.e_Korea1, "AdobeMyungjoStd-Medium.otf");
				// PDFNet.AddFontSubst(PDFNet.CharacterOrdering.e_CNS1, "AdobeSongStd-Light.otf");
				// PDFNet.AddFontSubst(PDFNet.CharacterOrdering.e_GB1, "AdobeMingStd-Light.otf");
			}
			catch (Exception)
			{
				Console.WriteLine("The specified color profile was not found.");
			}
            
			// Relative path to the folder containing test files.

			PDFDraw draw = new PDFDraw();  // PDFDraw class is used to rasterize PDF pages.

			// A hint object used to tell the rasterizer and the export
			// filter to generate and output the image in CMYK color space.
			ObjSet hints = new ObjSet();
			Obj cmyk_hint = hints.CreateDict();
			cmyk_hint.PutName("ColorSpace", "CMYK");

			//--------------------------------------------------------------------------------
			// Example 1) Convert the first PDF page to CMYK TIFF at 92 DPI. 
			// A three step tutorial to convert PDF page to an image.
			try  
			{
				// A) Open the PDF document.
				PDFDoc doc = new PDFDoc(input_path + "tiger.pdf");
				// Initialize the security handler, in case the PDF is encrypted.
				doc.InitSecurityHandler();  

				// B) The output resolution is set to 92 DPI.
				draw.SetDPI(92);

				// C) Rasterize the first page in the document and save the result as TIFF.
				Page pg = doc.GetPage(1);
				draw.Export(pg, output_path + "out1.tif", "TIFF", cmyk_hint);
				Console.WriteLine("Example 1: Done.");
			}
			catch (PDFNetException e) {
				Console.WriteLine(e.Message);
			}

			//--------------------------------------------------------------------------------
			// Example 2) Convert the all pages in a given document to CMYK TIFF.
			Console.WriteLine("Example 2:");
			try  
			{
				PDFDoc doc = new PDFDoc(input_path + "newsletter.pdf");
				// Initialize the security handler, in case the PDF is encrypted.
				doc.InitSecurityHandler();  
				
				draw.SetDPI(200); // Set the output resolution is to 200 DPI.

				// Traverse all pages in the document.
				for (PageIterator itr=doc.GetPageIterator(); itr.HasNext(); itr.Next()) {
					string outname = string.Format("{0}out2{1:d}.tif", output_path, itr.GetPageNumber());
					Console.WriteLine(outname);
					draw.Export(itr.Current(), outname, "TIFF", cmyk_hint);
				}

				Console.WriteLine("Done");
			}
			catch (PDFNetException e) 
			{
				Console.WriteLine(e.Message);
			}

			// Calling Dispose() on PDFDraw when it is not loger in use 
			// results in increased performance and can lower memory consumption.
			draw.Dispose();  
		}
	}
}
